pub struct IntraFramePeriod(/* private fields */);Expand description
A period in frames after which a new I-Frame is generated.
Implementations
Sourceimpl IntraFramePeriod
impl IntraFramePeriod
Sourcepub const fn from_num_frames(frames: u32) -> Self
pub const fn from_num_frames(frames: u32) -> Self
Creates a period in which I-Frames (group of pictures, “GOP size”) are generated.
Using lower values improves error resilience and allows for faster seeking within the video, but increases the overall required bitrate.
Setting the value to zero is equal to calling IntraFramePeriod::auto().