QpRange

Struct QpRange 

pub struct QpRange { /* private fields */ }
Quantization parameter range to control the degree of compression.

This can be used to control the balance between size and video quality.

Implementations

Source

impl QpRange

pub const fn new(min: u8, max: u8) -> Self

Limit the quantization of the encoder to the given range.

Valid values for min and max are between 0 and 51, where 0 represents highest quality and 51 the strongest compression.

Panics

Panics if max > 51 or if min > max.