pub struct QpRange { /* private fields */ }Expand description
Quantization parameter range to control the degree of compression.
This can be used to control the balance between size and video quality.
Implementations